@@ -24,23 +24,24 @@
 #'
 #' library(ustfd)
 #' ustfd_query(
-#'   '/v2/accounting/od/utf_qtr_yields',
+#'   'v2/accounting/od/utf_qtr_yields',
 #'    filter = list(record_date = c('>=' = lubridate::today()-10))
 #' )
 #' ustfd_query(
-#'   '/v2/accounting/od/utf_qtr_yields',
+#'   'v2/accounting/od/utf_qtr_yields',
 #'    filter = list(record_date = list('in' = c('2020-03-15','2020-03-16','2020-03-17')))
 #' )
 #' ustfd_query(
-#'   '/v2/accounting/od/utf_qtr_yields',
+#'   'v2/accounting/od/utf_qtr_yields',
 #'    filter = list(record_date = c('=' = '2020-03-15'))
 #' )
 #'
 #'
 #'
-ustfd_query <- function(endpoint, filter=NA, fields=NA, sort=NA, page_size=NA, page_number=NA){
-  if(! endpoint %in% .ustfd_endpoints$endpoint)
-    rlang::warn(paste0('Endpoint "', endpoint,'" not known. see data ustfd_endpoints.'))
+ustfd_query <- function(endpoint, filter=NULL, fields=NULL, sort=NULL, page_size=NULL, page_number=NULL){
+  endpoint <- leading_slash(endpoint)
+  if(! endpoint_exists(endpoint))
+    rlang::warn(paste0('Endpoint "', endpoint,'" not known. see data ustfd_tables.'))
 
   query <- list(
     format = 'json',
@@ -52,9 +53,11 @@ ustfd_query <- function(endpoint, filter=NA, fields=NA, sort=NA, page_size=NA, p
     page_number = page_number
   )
 
-  return(query[!is.na(query)])
+  return(purrr::compact(query[!is.na(query)]))
 }
 
-# fed_tax_deposits <- function(...){
-#   ustfd_query(endpoint = '/v1/accounting/dts/dts_table_4', ...)
-# }
+leading_slash <- function(endpoints){
+  idx <- which(substr(endpoints,1,1) == '/')
+  endpoints[idx] <- substr(endpoints[idx], 2, nchar(endpoints[idx]))
+  return(endpoints)
+}
